@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.14';
+    $VERSION  = '0.15';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -123,11 +123,11 @@ sub parse_xml
                 my $node = Excel::Template::Factory->create_node($name, @_);
                 die "'$name' (@_) didn't make a node!\n" unless defined $node;
 
-                if ($name eq 'WORKBOOK')
+                if ( $node->isa( 'WORKBOOK' ) )
                 {
                     push @{$self->{WORKBOOKS}}, $node;
                 }
-                elsif ($name eq 'VAR')
+                elsif ( $node->is_embedded )
                 {
                     return unless @stack;
                                                                                 
@@ -347,6 +347,16 @@ but I expect to be adding on to it very soon.
 
 There is a mailing list at http://groups-beta.google.com/group/ExcelTemplate
 
+Robert Graff -
+
+=over 4
+
+=item * Finishing formats
+
+=item * Fixing several bugs in worksheet naming
+
+=back 4
+
 =head1 COPYRIGHT
 
 This program is free software; you can redistribute
