@@ -23,12 +23,6 @@ sub resolve
     my @refs = $context->get_all_references( $ref_name );
     return '' unless @refs;
 
-    return $self->_join_refs(@refs);
-}
-
-sub _join_refs {
-    my ($self, @refs) = @_;
-    
     my ($top, $left, $bottom, $right) =
         ( $refs[0][0], $refs[0][1] ) x 2;
 
@@ -56,12 +50,12 @@ Excel::Template::Element::Range
 
 =head1 PURPOSE
 
-Returns a range of cell locations (i.e. B2:C2) that contains all calls using
-this reference. To return the location of the last cell, use BACKREF.
+Returns a range of cell locations (i.e. B2:C2) that contains all calls using this
+reference. To return the location of the last cell, use REF.
 
 =head1 NODE NAME
 
-RANGE
+REF
 
 =head1 INHERITANCE
 
@@ -75,7 +69,7 @@ Excel::Template::Element
 
 This is the name of the reference to look up.
 
-=back
+=back 4
 
 =head1 CHILDREN
 
@@ -108,6 +102,6 @@ Rob Kinyon (rkinyon@columbus.rr.com)
 
 =head1 SEE ALSO
 
-CELL, BACKREF
+CELL, REF
 
 =cut
